@@ -1,11 +1,12 @@
 /*
- * $Id: getpcaps.c,v 1.1 1998/04/30 02:53:00 morgan Exp morgan $
+ * $Id: getpcaps.c,v 1.3 1998/06/08 00:16:58 morgan Exp $
  *
  * Copyright (c) 1997 Andrew G. Morgan  <morgan@linux.kernel.org>
  *
  * This displays the capabilities of a given file.
  */
 
+#include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
@@ -16,9 +17,10 @@
 static void usage(void)
 {
     fprintf(stderr,
-	    "usage: whatcaps <pid> [<pid> ...]\n"
-	    "\n"
-	    "\tdisplays the capabilities on the queried process(es).\n"
+"usage: getcaps <pid> [<pid> ...]\n\n"
+"  This program displays the capabilities on the queried process(es).\n"
+"  The capabilities are displayed in the cap_from_text(3) format.\n\n"
+"[Copyright (c) 1997-8 Andrew G. Morgan  <morgan@linux.kernel.org>]\n"
 	);
     exit(1);
 }
@@ -61,6 +63,12 @@ int main(int argc, char **argv)
 
 /*
  * $Log: getpcaps.c,v $
+ * Revision 1.3  1998/06/08 00:16:58  morgan
+ * change to accommodate alpha (glibc?)
+ *
+ * Revision 1.2  1998/06/07 01:49:39  morgan
+ * added copyright info and some usage info.  Small tidy up.
+ *
  * Revision 1.1  1998/04/30 02:53:00  morgan
  * Initial revision
  *
